%global version 2.38.2
# rpmrelease is appended if betarelease != 0, otherwise becomes release
%global rpmrelease 1
# betarelease is either 0 or something like rc.1
%global betarelease 0

%if "%{betarelease}" == "0"
%global distversion %{version}
%global release %{rpmrelease}%{?dist}
%else
%global distversion %{version}-%{betarelease}
%global release 0.%{betarelease}.%{rpmrelease}%{?dist}
%endif

Summary: SnappyMail is a simple, modern and fast web-based email client
Name: snappymail
Version: %{version}
Release: %{release}
License: AGPL-3.0-or-later AND GPL-3.0-only AND GPL-3.0-or-later AND LGPL-2.1-or-later AND MPL-1.1 AND MIT AND BSD-3-Clause
URL: https://snappymail.eu/
Packager: Simon Matter <simon.matter@invoca.ch>
Vendor: Invoca Systems
Distribution: Invoca Linux Server
Group: Applications/Internet
Source0: https://github.com/the-djmaze/snappymail/releases/download/v%{distversion}/%{name}-%{distversion}.tar.gz
Source1: snappymail-2.3.5-apache24.conf
Source2: snappymail-2.4.3-php-fpm73.conf
Source3: snappymail-2.36.4-localhost.json
Source4: snappymail-README.RPM
Patch0: snappymail-2.10.0-config.patch
Patch1: snappymail-2.37.2-defaults.patch
Patch2: snappymail-2.24.0-localdate.patch
# patches => 100 should/will be fixed in SCM
BuildArch: noarch
BuildRequires: sed
Requires: php-fpm >= 7.4.0, php-json, php-mbstring, php-pdo, php-xml
Requires: php(httpd), httpd-filesystem >= 2.4.0
BuildRoot: %{_tmppath}/%{name}-%{version}-root

%description
SnappyMail Webmail is a simple, modern and fast web-based email client.
It supports IMAP and SMTP protocols (including TLS), Sieve scripts, multiple
accounts and identities and a manager panel for configuration. Plugins can be
installed to further extend functionality. Mails are not stored locally but
are accessed through the IMAP protocol on the mail server.

%prep
%setup -q -c -n %{name}-%{distversion}
%patch0 -p1 -b .patch-config

cd %{name}/v/%{distversion}
%patch1 -p4 -b .patch-defaults
%patch2 -p4 -b .patch-localdate
cd -

# install additional files
%{__install} -m 0644 -p %{SOURCE4} README.RPM

# fix permissions
find . -type f -exec %{__chmod} -x {} \;
%{__chmod} -R og-w .

%build
# activate custom config
%{__mv} -f _include.php include.php

# do some global renaming from rainloop to snappymail
find . -type f | while read -rs F; do
  %{__sed} -i".sed" \
    -e "s@rainloop\.user@snappymail@g" \
    -e "s@RAINLOOP:SIEVE@SNAPPYMAIL:SIEVE@g" \
    "$F"
  if cmp -s "${F}.sed" "$F"; then
    %{__mv} -f "${F}.sed" "$F"
  else
    %{__rm} -f "${F}.sed"
  fi
done

# remove compressed .js and .css files
find %{name}/v/%{distversion}/static \
  -type f \( -name "*.js" -o -name "*.css" \) | while read -rs F; do
  %{__rm} -f "${F}.br" "${F}.gz"
done

# on config save in admin page, the last NL gets removed
head -c -1 %{name}/v/%{distversion}/app/domains/disabled > \
  %{name}/v/%{distversion}/app/domains/disabled.$$
%{__mv} -f %{name}/v/%{distversion}/app/domains/disabled.$$ \
  %{name}/v/%{distversion}/app/domains/disabled

%install
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%{__install} -d %{buildroot}%{_sysconfdir}/%{name}/domains
%{__install} -d %{buildroot}%{_sysconfdir}/httpd/conf.d
%{__install} -d %{buildroot}%{_sysconfdir}/php-fpm.d
%{__install} -d %{buildroot}%{_datadir}/%{name}
%{__install} -d %{buildroot}%{_localstatedir}/lib/%{name}/_data_/_default_

%{__install} -m 0644 -p %{SOURCE1} %{buildroot}%{_sysconfdir}/httpd/conf.d/%{name}.conf
%{__install} -m 0644 -p %{SOURCE2} %{buildroot}%{_sysconfdir}/php-fpm.d/%{name}.conf
%{__install} -m 0600 -p %{SOURCE3} %{buildroot}%{_sysconfdir}/%{name}/domains/localhost.json
%{__install} -m 0600 -p %{name}/v/%{distversion}/app/domains/disabled \
  %{buildroot}%{_sysconfdir}/%{name}/domains/

# create .default config files
%{__install} -m 0600 -p %{buildroot}%{_sysconfdir}/%{name}/domains/localhost.json{,.default}
%{__install} -m 0600 -p %{buildroot}%{_sysconfdir}/%{name}/domains/disabled{,.default}

# remove files we don't need
find . -name "*.*.patch-*" -exec %{__rm} -vf {} \;
find . -name ".htaccess" -exec %{__rm} -vf {} \;

# move used files and directories in place
%{__mv} -f *.php %{name}/v/%{distversion} %{buildroot}%{_datadir}/%{name}/
%{__rm} -f data/README.md
%{__mv} -f data/* %{buildroot}%{_localstatedir}/lib/%{name}/

# these directories should be empty now, otherwise rmdir will fail
rmdir -p %{name}/v
rmdir data

# create config symlinks
%{__ln_s} -f ../../../../..%{_sysconfdir}/%{name} \
  %{buildroot}%{_localstatedir}/lib/%{name}/_data_/_default_/configs
%{__ln_s} -f ../../../../..%{_sysconfdir}/%{name}/domains \
  %{buildroot}%{_localstatedir}/lib/%{name}/_data_/_default_/domains

# reduce directory levels with symlinks
%{__ln_s} -f . %{buildroot}%{_datadir}/%{name}/%{name}
%{__ln_s} -f . %{buildroot}%{_datadir}/%{name}/v

%clean
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc README.md README.RPM
%config(noreplace) %{_sysconfdir}/httpd/conf.d/%{name}.conf
%config(noreplace) %{_sysconfdir}/php-fpm.d/%{name}.conf
%attr(0750,apache,root) %dir %{_sysconfdir}/%{name}
%attr(0750,apache,root) %dir %{_sysconfdir}/%{name}/domains
%ghost %attr(0600,apache,apache) %config(missingok) %{_sysconfdir}/%{name}/application.ini
%attr(0600,apache,apache) %config(missingok,noreplace) %verify(not md5 size mtime) %{_sysconfdir}/%{name}/domains/localhost.json
%attr(0600,apache,apache) %config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/%{name}/domains/disabled
%attr(0600,root,root) %{_sysconfdir}/%{name}/domains/*.default
%{_datadir}/%{name}
%attr(0700,apache,apache) %dir %{_localstatedir}/lib/%{name}
%attr(0700,apache,apache) %dir %{_localstatedir}/lib/%{name}/_data_
%attr(0700,apache,apache) %dir %{_localstatedir}/lib/%{name}/_data_/_default_
%attr(0600,apache,apache) %verify(not mtime) %{_localstatedir}/lib/%{name}/VERSION
%{_localstatedir}/lib/%{name}/_data_/_default_/*

%changelog
* Thu Oct 10 2024 Simon Matter <simon.matter@invoca.ch> 2.38.2-1
- upgrade to 2.38.2

* Wed Oct 09 2024 Simon Matter <simon.matter@invoca.ch> 2.38.1-1
- upgrade to 2.38.1

* Wed Sep 18 2024 Simon Matter <simon.matter@invoca.ch> 2.38.0-1
- upgrade to 2.38.0

* Wed Aug 28 2024 Simon Matter <simon.matter@invoca.ch> 2.37.3-1
- upgrade to 2.37.3

* Tue Aug 13 2024 Simon Matter <simon.matter@invoca.ch> 2.37.2-1
- upgrade to 2.37.2

* Tue Jun 25 2024 Simon Matter <simon.matter@invoca.ch> 2.36.4-1
- upgrade to 2.36.4

* Tue Jun 25 2024 Simon Matter <simon.matter@invoca.ch> 2.36.3-5
- strip last NL from disabled file

* Mon Jun 24 2024 Simon Matter <simon.matter@invoca.ch> 2.36.3-4
- add another patch to fix #1640

* Sun Jun 23 2024 Simon Matter <simon.matter@invoca.ch> 2.36.3-3
- add patch to fix #1640

* Thu Jun 20 2024 Simon Matter <simon.matter@invoca.ch> 2.36.3-2
- clarify password generation in README.RPM

* Tue May 28 2024 Simon Matter <simon.matter@invoca.ch> 2.36.3-1
- upgrade to 2.36.3

* Mon May 27 2024 Simon Matter <simon.matter@invoca.ch> 2.36.2-1
- upgrade to 2.36.2

* Wed Apr 24 2024 Simon Matter <simon.matter@invoca.ch> 2.36.1-1
- upgrade to 2.36.1

* Wed Mar 27 2024 Simon Matter <simon.matter@invoca.ch> 2.36.0-1
- upgrade to 2.36.0

* Mon Mar 18 2024 Simon Matter <simon.matter@invoca.ch> 2.35.4-1
- upgrade to 2.35.4

* Wed Mar 13 2024 Simon Matter <simon.matter@invoca.ch> 2.35.3-1
- upgrade to 2.35.3

* Wed Feb 28 2024 Simon Matter <simon.matter@invoca.ch> 2.35.2-1
- upgrade to 2.35.2

* Thu Feb 22 2024 Simon Matter <simon.matter@invoca.ch> 2.35.0-1
- upgrade to 2.35.0

* Thu Feb 15 2024 Simon Matter <simon.matter@invoca.ch> 2.34.2-1
- upgrade to 2.34.2

* Wed Feb 14 2024 Simon Matter <simon.matter@invoca.ch> 2.34.1-1
- upgrade to 2.34.1

* Tue Jan 23 2024 Simon Matter <simon.matter@invoca.ch> 2.33.0-1
- upgrade to 2.33.0

* Wed Jan 17 2024 Simon Matter <simon.matter@invoca.ch> 2.32.0-1
- upgrade to 2.32.0

* Sat Dec 09 2023 Simon Matter <simon.matter@invoca.ch> 2.31.0-1
- upgrade to 2.31.0

* Mon Dec 04 2023 Simon Matter <simon.matter@invoca.ch> 2.30.0-1
- upgrade to 2.30.0

* Wed Nov 22 2023 Simon Matter <simon.matter@invoca.ch> 2.29.4-1
- upgrade to 2.29.4

* Wed Nov 15 2023 Simon Matter <simon.matter@invoca.ch> 2.29.2-1
- upgrade to 2.29.2

* Tue Oct 03 2023 Simon Matter <simon.matter@invoca.ch> 2.29.1-1
- upgrade to 2.29.1

* Tue Jul 11 2023 Simon Matter <simon.matter@invoca.ch> 2.28.4-1
- upgrade to 2.28.4

* Fri Jun 23 2023 Simon Matter <simon.matter@invoca.ch> 2.28.3-1
- upgrade to 2.28.3

* Tue Jun 20 2023 Simon Matter <simon.matter@invoca.ch> 2.28.2-1
- upgrade to 2.28.2

* Tue Jun 06 2023 Simon Matter <simon.matter@invoca.ch> 2.28.1-1
- upgrade to 2.28.1

* Wed May 31 2023 Simon Matter <simon.matter@invoca.ch> 2.28.0-1
- upgrade to 2.28.0

* Thu Apr 06 2023 Simon Matter <simon.matter@invoca.ch> 2.27.3-1
- upgrade to 2.27.3

* Wed Mar 22 2023 Simon Matter <simon.matter@invoca.ch> 2.27.2-1
- upgrade to 2.27.2

* Tue Mar 21 2023 Simon Matter <simon.matter@invoca.ch> 2.27.0-1
- upgrade to 2.27.0

* Sat Feb 25 2023 Simon Matter <simon.matter@invoca.ch> 2.26.4-1
- upgrade to 2.26.4

* Fri Feb 24 2023 Simon Matter <simon.matter@invoca.ch> 2.26.3-1
- upgrade to 2.26.3

* Sat Feb 18 2023 Simon Matter <simon.matter@invoca.ch> 2.26.2-1
- upgrade to 2.26.2

* Wed Feb 15 2023 Simon Matter <simon.matter@invoca.ch> 2.26.1-1
- upgrade to 2.26.1

* Sat Feb 11 2023 Simon Matter <simon.matter@invoca.ch> 2.26.0-1
- upgrade to 2.26.0

* Fri Feb 10 2023 Simon Matter <simon.matter@invoca.ch> 2.25.5-1
- upgrade to 2.25.5

* Tue Feb 07 2023 Simon Matter <simon.matter@invoca.ch> 2.25.4-1
- upgrade to 2.25.4

* Sat Feb 04 2023 Simon Matter <simon.matter@invoca.ch> 2.25.3-1
- upgrade to 2.25.3

* Fri Feb 03 2023 Simon Matter <simon.matter@invoca.ch> 2.25.2-1
- upgrade to 2.25.2

* Tue Jan 31 2023 Simon Matter <simon.matter@invoca.ch> 2.25.1-1
- upgrade to 2.25.1

* Fri Jan 27 2023 Simon Matter <simon.matter@invoca.ch> 2.25.0-1
- upgrade to 2.25.0

* Fri Jan 20 2023 Simon Matter <simon.matter@invoca.ch> 2.24.6-1
- upgrade to 2.24.6

* Fri Jan 13 2023 Simon Matter <simon.matter@invoca.ch> 2.24.5-1
- upgrade to 2.24.5

* Sat Dec 31 2022 Simon Matter <simon.matter@invoca.ch> 2.24.4-1
- upgrade to 2.24.4

* Thu Dec 29 2022 Simon Matter <simon.matter@invoca.ch> 2.24.3-1
- upgrade to 2.24.3

* Wed Dec 28 2022 Simon Matter <simon.matter@invoca.ch> 2.24.2-1
- upgrade to 2.24.2

* Sat Dec 24 2022 Simon Matter <simon.matter@invoca.ch> 2.24.1-1
- upgrade to 2.24.1

* Fri Dec 23 2022 Simon Matter <simon.matter@invoca.ch> 2.24.0-1
- upgrade to 2.24.0

* Fri Dec 16 2022 Simon Matter <simon.matter@invoca.ch> 2.23.1-1
- upgrade to 2.23.1

* Fri Dec 09 2022 Simon Matter <simon.matter@invoca.ch> 2.23.0-1
- upgrade to 2.23.0

* Wed Dec 07 2022 Simon Matter <simon.matter@invoca.ch> 2.22.7-1
- upgrade to 2.22.7

* Tue Dec 06 2022 Simon Matter <simon.matter@invoca.ch> 2.22.6-1
- upgrade to 2.22.6

* Sat Dec 03 2022 Simon Matter <simon.matter@invoca.ch> 2.22.5-1
- upgrade to 2.22.5

* Tue Nov 29 2022 Simon Matter <simon.matter@invoca.ch> 2.22.4-1
- upgrade to 2.22.4

* Mon Nov 28 2022 Simon Matter <simon.matter@invoca.ch> 2.22.3-1
- upgrade to 2.22.3

* Fri Nov 18 2022 Simon Matter <simon.matter@invoca.ch> 2.21.3-1
- upgrade to 2.21.3

* Wed Nov 16 2022 Simon Matter <simon.matter@invoca.ch> 2.21.2-1
- upgrade to 2.21.2

* Mon Nov 14 2022 Simon Matter <simon.matter@invoca.ch> 2.21.1-1
- upgrade to 2.21.1

* Sat Nov 12 2022 Simon Matter <simon.matter@invoca.ch> 2.21.0-1
- upgrade to 2.21.0

* Wed Nov 09 2022 Simon Matter <simon.matter@invoca.ch> 2.20.6-1
- upgrade to 2.20.6

* Tue Nov 08 2022 Simon Matter <simon.matter@invoca.ch> 2.20.2-1
- upgrade to 2.20.2

* Fri Nov 04 2022 Simon Matter <simon.matter@invoca.ch> 2.20.0-1
- upgrade to 2.20.0

* Thu Nov 03 2022 Simon Matter <simon.matter@invoca.ch> 2.19.7-1
- upgrade to 2.19.7

* Tue Nov 01 2022 Simon Matter <simon.matter@invoca.ch> 2.19.6-1
- upgrade to 2.19.6

* Fri Oct 28 2022 Simon Matter <simon.matter@invoca.ch> 2.19.4-1
- upgrade to 2.19.4

* Sat Oct 22 2022 Simon Matter <simon.matter@invoca.ch> 2.19.2-1
- upgrade to 2.19.2

* Thu Oct 13 2022 Simon Matter <simon.matter@invoca.ch> 2.18.6-1
- upgrade to 2.18.6

* Sat Oct 08 2022 Simon Matter <simon.matter@invoca.ch> 2.18.5-1
- upgrade to 2.18.5

* Wed Oct 05 2022 Simon Matter <simon.matter@invoca.ch> 2.18.4-1
- upgrade to 2.18.4

* Sat Oct 01 2022 Simon Matter <simon.matter@invoca.ch> 2.18.3-1
- upgrade to 2.18.3

* Mon Sep 26 2022 Simon Matter <simon.matter@invoca.ch> 2.18.2-1
- upgrade to 2.18.2

* Thu Sep 22 2022 Simon Matter <simon.matter@invoca.ch> 2.18.1-1
- upgrade to 2.18.1

* Fri Sep 09 2022 Simon Matter <simon.matter@invoca.ch> 2.18.0-1
- upgrade to 2.18.0

* Fri Sep 02 2022 Simon Matter <simon.matter@invoca.ch> 2.17.4-1
- upgrade to 2.17.4

* Tue Aug 30 2022 Simon Matter <simon.matter@invoca.ch> 2.17.3-1
- upgrade to 2.17.3

* Tue Aug 09 2022 Simon Matter <simon.matter@invoca.ch> 2.17.2-1
- upgrade to 2.17.2

* Fri Aug 05 2022 Simon Matter <simon.matter@invoca.ch> 2.17.1-1
- upgrade to 2.17.1

* Wed Jul 20 2022 Simon Matter <simon.matter@invoca.ch> 2.17.0-1
- upgrade to 2.17.0

* Tue May 31 2022 Simon Matter <simon.matter@invoca.ch> 2.16.3-1
- upgrade to 2.16.3

* Fri May 20 2022 Simon Matter <simon.matter@invoca.ch> 2.16.1-1
- upgrade to 2.16.1

* Mon May 16 2022 Simon Matter <simon.matter@invoca.ch> 2.15.3-1
- upgrade to 2.15.3

* Fri May 13 2022 Simon Matter <simon.matter@invoca.ch> 2.15.2-1
- upgrade to 2.15.2

* Mon May 02 2022 Simon Matter <simon.matter@invoca.ch> 2.15.1-1
- upgrade to 2.15.1

* Mon Apr 25 2022 Simon Matter <simon.matter@invoca.ch> 2.15.0-1
- upgrade to 2.15.0

* Wed Apr 06 2022 Simon Matter <simon.matter@invoca.ch> 2.14.3-1
- upgrade to 2.14.3

* Wed Mar 23 2022 Simon Matter <simon.matter@invoca.ch> 2.14.1-1
- upgrade to 2.14.1

* Tue Mar 22 2022 Simon Matter <simon.matter@invoca.ch> 2.14.0-1
- upgrade to 2.14.0

* Fri Mar 11 2022 Simon Matter <simon.matter@invoca.ch> 2.13.4-1
- upgrade to 2.13.4

* Wed Mar 09 2022 Simon Matter <simon.matter@invoca.ch> 2.13.3-1
- upgrade to 2.13.3

* Mon Mar 07 2022 Simon Matter <simon.matter@invoca.ch> 2.13.2-1
- upgrade to 2.13.2

* Tue Mar 01 2022 Simon Matter <simon.matter@invoca.ch> 2.13.1-1
- upgrade to 2.13.1

* Wed Feb 16 2022 Simon Matter <simon.matter@invoca.ch> 2.12.2-1
- upgrade to 2.12.2

* Tue Feb 15 2022 Simon Matter <simon.matter@invoca.ch> 2.12.1-1
- upgrade to 2.12.1

* Mon Feb 14 2022 Simon Matter <simon.matter@invoca.ch> 2.12.0-1
- upgrade to 2.12.0

* Sat Jan 15 2022 Simon Matter <simon.matter@invoca.ch> 2.11.0-1
- upgrade to 2.11.0

* Thu Jan 13 2022 Simon Matter <simon.matter@invoca.ch> 2.10.3-1
- upgrade to 2.10.3

* Sat Jan 08 2022 Simon Matter <simon.matter@invoca.ch> 2.10.2-1
- upgrade to 2.10.2

* Fri Jan 07 2022 Simon Matter <simon.matter@invoca.ch> 2.10.1-1
- upgrade to 2.10.1

* Wed Dec 15 2021 Simon Matter <simon.matter@invoca.ch> 2.10.0-1
- upgrade to 2.10.0

* Wed Dec 15 2021 Simon Matter <simon.matter@invoca.ch> 2.9.6-1
- upgrade to 2.9.6

* Thu Dec 09 2021 Simon Matter <simon.matter@invoca.ch> 2.9.5-1
- upgrade to 2.9.5

* Thu Dec 02 2021 Simon Matter <simon.matter@invoca.ch> 2.9.4-1
- upgrade to 2.9.4

* Mon Nov 22 2021 Simon Matter <simon.matter@invoca.ch> 2.9.3-1
- upgrade to 2.9.3

* Thu Nov 18 2021 Simon Matter <simon.matter@invoca.ch> 2.9.2-2
- add patch to fix issue #162

* Thu Nov 18 2021 Simon Matter <simon.matter@invoca.ch> 2.9.2-1
- upgrade to 2.9.2

* Mon Nov 15 2021 Simon Matter <simon.matter@invoca.ch> 2.9.1-1
- upgrade to 2.9.1

* Tue Nov 09 2021 Simon Matter <simon.matter@invoca.ch> 2.9.0-1
- upgrade to 2.9.0

* Fri Nov 05 2021 Simon Matter <simon.matter@invoca.ch> 2.8.2-1
- upgrade to 2.8.2

* Thu Nov 04 2021 Simon Matter <simon.matter@invoca.ch> 2.8.1-1
- upgrade to 2.8.1

* Sat Oct 30 2021 Simon Matter <simon.matter@invoca.ch> 2.8.0-1
- upgrade to 2.8.0

* Tue Oct 12 2021 Simon Matter <simon.matter@invoca.ch> 2.7.3-1
- upgrade to 2.7.3

* Tue Sep 28 2021 Simon Matter <simon.matter@invoca.ch> 2.7.2-1
- upgrade to 2.7.2

* Wed Sep 15 2021 Simon Matter <simon.matter@invoca.ch> 2.7.1-1
- upgrade to 2.7.1

* Thu Sep 02 2021 Simon Matter <simon.matter@invoca.ch> 2.7.0-1
- upgrade to 2.7.0

* Wed Aug 18 2021 Simon Matter <simon.matter@invoca.ch> 2.6.2-1
- upgrade to 2.6.2

* Wed Aug 11 2021 Simon Matter <simon.matter@invoca.ch> 2.6.1-1
- upgrade to 2.6.1

* Thu Jul 29 2021 Simon Matter <simon.matter@invoca.ch> 2.6.0-1
- upgrade to 2.6.0

* Wed Jul 21 2021 Simon Matter <simon.matter@invoca.ch> 2.5.3-1
- upgrade to 2.5.3

* Fri Jun 11 2021 Simon Matter <simon.matter@invoca.ch> 2.5.2-1
- upgrade to 2.5.2

* Thu May 20 2021 Simon Matter <simon.matter@invoca.ch> 2.5.1-1
- upgrade to 2.5.1

* Tue Apr 20 2021 Simon Matter <simon.matter@invoca.ch> 2.5.0-1
- upgrade to 2.5.0

* Thu Apr 15 2021 Simon Matter <simon.matter@invoca.ch> 2.5.0-0.rc.4.1
- upgrade to 2.5.0-rc.4

* Tue Apr 13 2021 Simon Matter <simon.matter@invoca.ch> 2.5.0-0.rc.3.1
- upgrade to 2.5.0-rc.3

* Fri Apr 09 2021 Simon Matter <simon.matter@invoca.ch> 2.5.0-0.rc.2.1
- upgrade to 2.5.0-rc.2

* Fri Apr 09 2021 Simon Matter <simon.matter@invoca.ch> 2.5.0-0.rc.1.1
- upgrade to 2.5.0-rc.1

* Thu Apr 08 2021 Simon Matter <simon.matter@invoca.ch> 2.4.3-3
- enable zlib.output_compression in php config
- remove initial_password handling

* Wed Apr 07 2021 Simon Matter <simon.matter@invoca.ch> 2.4.3-2
- remove compressed .js and .css files

* Tue Mar 30 2021 Simon Matter <simon.matter@invoca.ch> 2.4.3-1
- upgrade to release 2.4.3

* Fri Mar 26 2021 Simon Matter <simon.matter@invoca.ch> 2.4.2-3
- change default of 'use_imap_list_subscribe' to Off

* Fri Mar 26 2021 Simon Matter <simon.matter@invoca.ch> 2.4.2-2
- add .default config files

* Thu Mar 25 2021 Simon Matter <simon.matter@invoca.ch> 2.4.2-1
- upgrade to release 2.4.2

* Wed Mar 24 2021 Simon Matter <simon.matter@invoca.ch> 2.4.1-4
- add some global renaming from rainloop to snappymail

* Wed Mar 24 2021 Simon Matter <simon.matter@invoca.ch> 2.4.1-3
- add patch to change sieve script name to snappymail

* Mon Mar 22 2021 Simon Matter <simon.matter@invoca.ch> 2.4.1-2
- add patch to fix issue #65

* Fri Mar 19 2021 Simon Matter <simon.matter@invoca.ch> 2.4.1-1
- upgrade to release 2.4.1

* Fri Mar 19 2021 Simon Matter <simon.matter@invoca.ch> 2.4.0-1
- upgrade to release 2.4.0

* Thu Mar 18 2021 Simon Matter <simon.matter@invoca.ch> 2.3.5-1
- initial package
